@@ -57,6 +57,7 @@ SubscriptionConfig = namedtuple('SubscriptionConfig', ['streams',
                                                        'host',
                                                        'port',
                                                        'timeout',
+                                                       'max_time',
                                                        'page_size'])
 
 
@@ -249,8 +250,8 @@ class Page:
 
 class StreamReader:
 
-    def __init__(self, queue, stream_name, loop, instance_name, subscriptions_store, session, nosleep=False):
-        self._fetcher = StreamFetcher(None, loop=loop, nosleep=nosleep, session=session)
+    def __init__(self, queue, stream_name, loop, instance_name, max_time, subscriptions_store, session, nosleep=False):
+        self._fetcher = StreamFetcher(None, loop=loop, nosleep=nosleep, session=session, max_time=max_time)
         self._queue = queue
         self._loop = loop
         self._stream = stream_name
@@ -416,7 +417,7 @@ class state(Enum):
 
 class StreamFetcher:
 
-    def __init__(self, policy, loop, session, nosleep=False):
+    def __init__(self, policy, loop, session, max_time, nosleep=False):
         self._policy = policy
         self._loop = loop
         self._log = logging.getLogger(__name__)
@@ -424,6 +425,7 @@ class StreamFetcher:
         self._running = True
         self._sleep = None
         self._nosleep = nosleep
+        self._max_time = max_time
         self._exns = set()
         self.session = session
 
@@ -433,16 +435,15 @@ class StreamFetcher:
             self._sleep.cancel()
 
     def sleeps(self, uri):
-        max_time = 60
         attempts = 0
         last_time = 0
         self._state = state.amber
         while(True):
-            if(last_time < max_time):
+            if(last_time < self._max_time):
                 attempts = attempts + 1
             elif self._state == state.amber:
                 self._state = state.red
-                self._log.error(
+                self._log.warning(
                     "Stream fetcher has failed to connect to eventstore at %s in the last %d attempts",
                     uri,
                     attempts)
@@ -530,14 +531,24 @@ def _ensure_coroutine_function(func):
         return coroutine_function
 
 
+class ExceptionCause(Enum):
+    counter = "counter"
+    handler = "handler"
+
+
 class EventRaiser:
 
-    def __init__(self, queue, counter, callback, loop=None):
+    def __init__(self, queue, counter, callback, loop=None,
+                 exception_handler=None):
         self._queue = queue
-        self._callback = callback
         self._counter = counter
+        self._callback = callback
         self._loop = loop or asyncio.get_event_loop()
         self._logger = logging.getLogger(__name__)
+        self._exception_handler = exception_handler
+
+    def set_exception_handler(self, handler):
+        self._exception_handler = handler
 
     def stop(self):
         self._is_running = False
@@ -557,8 +568,16 @@ class EventRaiser:
                     self._counter[msg.stream] = msg.sequence
                 except pybreaker.CircuitBreakerError:
                     pass
-                except:
-                    self._logger.exception("Failed to persist last read event with {}".format(type(self._counter)))
+                except BaseException as e:
+                    if self._exception_handler is None:
+                        self._logger.exception(
+                            "Failed to persist last read event with {}".format(
+                                type(self._counter)))
+                    else:
+                        self._exception_handler(
+                            self._loop,
+                            {"exception": e,
+                             "atomicpuppy_cause": ExceptionCause.counter})
             except RejectedMessageException:
                 self._logger.warn("%s message %s was rejected and has not been processed",
                                   msg.type, msg.id)
@@ -566,14 +585,18 @@ class EventRaiser:
                 pass
             except Exception as e:
                 if 'msg' in locals():
-                    self._logger.exception("Failed to process message %s", msg)
+                    if self._exception_handler is None:
+                        self._logger.exception("Failed to process message %s", msg)
+                    else:
+                        self._exception_handler(
+                            self._loop,
+                            {"exception": e,
+                             "atomicpuppy_cause": ExceptionCause.handler,
+                             "atomicpuppy_message": msg})
                 else:
                     # Happens when the wait_for failed and msg was not poplated
                     self._logger.debug(str(e))
 
-
-
-
     async def consume_events(self):
         self._is_running = True
         while self._loop.is_running() and self._is_running:
@@ -668,6 +691,7 @@ class StreamConfigReader:
                                   host=cfg.get("host") or 'localhost',
                                   port=cfg.get("port") or 2113,
                                   timeout=cfg.get("timeout") or 20,
+                                  max_time=cfg.get("max_time") or 60,
                                   page_size=cfg.get("page_size") or 20)
 
     def _make_counter(self, cfg, instance):
@@ -824,7 +848,7 @@ class EventPublisher:
                     "metadata": event.metadata,
                 },
             )
-        auth = (self.username, self.password) if self.username and self.password else () 
+        auth = (self.username, self.password) if self.username and self.password else ()
         r = requests.post(
             uri,
             headers=headers,
