@@ -285,8 +285,8 @@ class StreamReaderContext:
         self.session = FakeClientSession(self.http)
         self._queue = asyncio.Queue(loop=self._loop)
 
-    def subscribe_and_run(self, stream, last_read=-1, nosleep=False):
-        self._reader = self.subscribeTo(stream, last_read, nosleep)
+    def subscribe_and_run(self, stream, last_read=-1, max_time=60, nosleep=False):
+        self._reader = self.subscribeTo(stream, last_read, max_time, nosleep)
         self.run_the_reader()
 
     def run_the_reader(self):
@@ -298,7 +298,7 @@ class StreamReaderContext:
     def create_counter(self):
         return lambda: self.counter
 
-    def subscribeTo(self, stream, last_read, nosleep=False):
+    def subscribeTo(self, stream, last_read, max_time, nosleep=False):
         assert(last_read is not None)
         config = SubscriptionConfig(
             streams=None,
@@ -307,6 +307,7 @@ class StreamReaderContext:
             host=self._host,
             port=self._port,
             timeout=20,
+            max_time=max_time,
             page_size=20)
 
         subscriptions_store = SubscriptionInfoStore(config, self.counter)
@@ -319,6 +320,7 @@ class StreamReaderContext:
             instance_name='foo',
             subscriptions_store=subscriptions_store,
             session=self.session,
+            max_time=max_time,
             nosleep=nosleep)
         return self._reader
 
@@ -420,7 +422,7 @@ class When_the_projected_events_contain_metadata(StreamReaderContext):
         assert self.the_events[3].stream == '$et-test-event'
 
     def the_events_should_published_stream(self):
-        assert self.the_events[3].published_stream == 'test-3f419d23-24dd-49b6-95b7-65467e0b48be' 
+        assert self.the_events[3].published_stream == 'test-3f419d23-24dd-49b6-95b7-65467e0b48be'
 
     def the_events_should_published_sequence(self):
         assert self.the_events[3].published_sequence == 0
@@ -481,7 +483,7 @@ class When_the_events_contain_metadata(StreamReaderContext):
         assert self.the_events[1].stream == 'test-0f6ffca0-e758-4289-824d-cade1c8a5c4f'
 
     def the_events_should_have_published_stream(self):
-        assert self.the_events[1].published_stream == 'test-0f6ffca0-e758-4289-824d-cade1c8a5c4f' 
+        assert self.the_events[1].published_stream == 'test-0f6ffca0-e758-4289-824d-cade1c8a5c4f'
 
     def the_events_should_have_published_sequence(self):
         assert self.the_events[1].published_sequence == 1
@@ -680,7 +682,7 @@ class When_events_are_added_after_the_first_run(StreamReaderContext):
             SCRIPT_PATH + '/responses/new-events/head_prev2_next_prev_prev.json')
 
     def because_we_run_the_reader_three_times(self):
-        self._reader = self.subscribeTo('stock', -1)
+        self._reader = self.subscribeTo('stock', -1, 60)
         self.run_the_reader()
         self.run_the_reader()
         self.run_the_reader()
@@ -764,7 +766,7 @@ class When_a_valueerror_occurs_during_fetch(StreamReaderContext):
     # note that we run with a real event loop, and don't explicitly
     # call stop. The exception will stop the loop.
     def because_we_start_the_reader(self):
-        self._reader = self.subscribeTo("my-stream", 1)
+        self._reader = self.subscribeTo("my-stream", 1, 60)
         with(self._log.capture()):
             self._loop.run_until_complete(
                 self._reader.start_consuming()
@@ -919,6 +921,31 @@ class When_a_client_response_error_occurs_during_fetch(StreamReaderContext):
                    for r in self._log._logs))
 
 
+class When_a_max_time_is_exceeded(StreamReaderContext):
+
+    _log = SpyLog()
+
+    def given_a_disconnection_error(self):
+        self.http.registerCallbacksUri(
+            'http://eventstore.local:2113/streams/newstream/0/forward/20',
+            [
+                fail_with_disconnected_error,
+                lambda: exec('raise ValueError()')
+            ]
+        )
+
+    def because_we_start_the_reader(self):
+        self.subscribe_and_run('newstream', max_time=1)
+
+    def it_should_log_a_warning(self):
+        assert(any(r.msg == "Error occurred while requesting %s"
+                   and r.levelno == logging.WARNING
+                   for r in self._log._logs))
+        assert(any(r.msg == "Stream fetcher has failed to connect to eventstore at %s in the last %d attempts"
+                   and r.levelno == logging.WARNING
+                   for r in self._log._logs))
+
+
 """
 If we get a 40x range message then something is wrong with our configuration,
 we should stop the loop and log an error.
